@@ -23,7 +23,6 @@ BEGIN {
       constant->import( MAKE => $make );
       last;
    }
-   die "OS unsupported - unable to find GNU make\n" unless defined &MAKE;
 
    # GNU libtool is called 'glibtool' on Darwin
    foreach my $libtool (qw( libtool glibtool )) {
@@ -35,15 +34,22 @@ BEGIN {
       constant->import( LIBTOOL => $libtool );
       last;
    }
-   die "OS unsupported - unable to find GNU libtool\n" unless defined &LIBTOOL;
-
 }
 
-use constant MAKEARGS => "LIBTOOL=".LIBTOOL;
+sub MAKEARGS { "LIBTOOL=".LIBTOOL() }
 
 __PACKAGE__->add_property( 'tarball' );
 __PACKAGE__->add_property( 'pkgconfig_module' );
 __PACKAGE__->add_property( 'pkgconfig_version' );
+__PACKAGE__->add_property( 'alien_requires' );
+
+# Modules that this code itself requires
+my %more_configure_requires = (
+   'File::Basename' => 0,
+   'File::Spec'     => 0,
+   'File::Path'     => '2.07',
+   'Module::Build'  => 0,
+);
 
 sub new
 {
@@ -57,8 +63,25 @@ sub new
       type  => "+",
    };
 
+
    my $self = $class->SUPER::new( %args );
 
+   foreach my $req ( @{ $self->alien_requires || [] } ) {
+      my $missing = $self->do_requires( @$req );
+      die "OS unsupported - missing $missing\n" if defined $missing;
+   }
+
+   my @reqs = @{ $self->alien_requires || [] };
+   while( @reqs ) {
+      my ( $name, @args ) = @{ shift @reqs };
+
+      push( @reqs, @args ), next if $name eq "any";
+
+      $self->configure_requires->{"ExtUtils::CChecker"} //= 0 if $name eq "header";
+   }
+
+   $self->configure_requires->{$_} ||= $more_configure_requires{$_} for keys %more_configure_requires;
+
    my $module = $self->pkgconfig_module;
    my $version = $self->pkgconfig_version;
 
@@ -66,6 +89,8 @@ sub new
       !$use_bundled and system( "pkg-config", $module, "--atleast-version", $version ) != 0;
 
    if( $use_bundled ) {
+      die "OS unsupported - unable to find GNU make\n" unless defined &MAKE;
+      die "OS unsupported - unable to find GNU libtool\n" unless defined &LIBTOOL;
       print "Building bundled source\n";
    }
    else {
@@ -77,6 +102,90 @@ sub new
    return $self;
 }
 
+{
+   my $eucc;
+
+   sub cchecker
+   {
+      my $self = shift;
+      return $eucc ||= do {
+         require ExtUtils::CChecker;
+         return ExtUtils::CChecker->new;
+      };
+   }
+}
+
+sub do_requires
+{
+   my $self = shift;
+   my ( $name, @args ) = @_;
+
+   my $code = $self->can( "do_requires_$name" ) or
+      die "Unrecognised 'alien_requires' requirement type '$name'\n";
+
+   return $self->$code( @args );
+}
+
+sub do_requires_any
+{
+   my $self = shift;
+   my @alts = @_;
+
+   my @missing;
+   foreach my $alt ( @alts ) {
+      my $ret = $self->do_requires( @$alt );
+      return if !$ret;
+
+      push @missing, $ret;
+   }
+
+   return $missing[0] if @missing < 2;
+   return "either $missing[0] or $missing[1]" if @missing == 2;
+   return "any of " . join( ", ", @missing[0 .. $#missing-1] ) . " or " . $missing[-1];
+}
+
+sub do_requires_pkgconfig
+{
+   my $self = shift;
+   my ( $module, %args ) = @_;
+
+   print "Looking for pkg-config $module... ";
+
+   my @cmdline;
+   push @cmdline, "--atleast-version=$args{atleast_version}" if defined $args{atleast_version};
+
+   if( system( "pkg-config", $module, @cmdline ) == 0 ) {
+      print "found\n";
+      return;
+   }
+
+   print "not found\n";
+   return "$module";
+}
+
+sub do_requires_header
+{
+   my $self = shift;
+   my ( $header ) = @_;
+
+   print "Looking for <$header>... ";
+
+   my $success = $self->cchecker->try_compile_run(
+      source => <<"EOC"
+#include <$header>
+int main(int argc, char *argv[]) {return 0;}
+EOC
+   );
+
+   if( $success ) {
+      print "found\n";
+      return;
+   }
+
+   print "not found\n";
+   return "<$header>";
+}
+
 sub _srcdir
 {
    my $self = shift;
@@ -107,7 +216,7 @@ sub make_in_srcdir
    my @args = @_;
 
    $self->in_srcdir( sub {
-      system( MAKE, MAKEARGS, @args ) == 0 or
+      system( MAKE(), MAKEARGS(), @args ) == 0 or
          die "Unable to make - $!";
    } );
 }
@@ -165,22 +274,38 @@ sub ACTION_code
 
       open( my $stamp, ">", $buildstamp ) or die "Unable to touch .build-stamp file - $!";
 
-      # Now hack the .pc file to put ${libdir}-relative paths in it
+      # The .pc file that 'make install' has written contains the build-time
+      # blib paths in it. We need that rewritten for the real install location,
+      # except we're not going to know where that is until ACTION_install.
+      # Instead, lets output a .pc.PL file that we can run at ACTION_install time
+      # to generate it.
       my $pcfile = "$libdir/pkgconfig/$pkgconfig_module.pc";
       if( -f $pcfile ) {
          open my $in, "<", $pcfile or die "Cannot open $pcfile for reading - $!";
-         open my $out, ">", "$pcfile.new" or die "Cannot open $pcfile.new for writing - $!";
+         open my $out, ">", "$pcfile.PL" or die "Cannot open $pcfile.PL for writing - $!";
+
+         print { $out } join "\n",
+            "#!/usr/bin/env perl",
+            "use File::Basename 'dirname';",
+            '$libdir = dirname(dirname($0));',
+           q{( my $config = <<'EOF' ) =~ s/\@LIBDIR@/$libdir/g;},
+            "";
 
          while( <$in> ) {
-            s{\Q$libdir\E}{\${libdir}}g;
+            s{\Q$libdir\E}{\@LIBDIR@}g;
             print { $out } $_;
          }
 
-         # Cygwin/Windows doesn't like it when you rename open files
+         print { $out } join "\n",
+            "EOF",
+            'print $config;',
+            "";
+
+         # Cygwin/Windows doesn't like it when you delete open files
          close $in;
          close $out;
 
-         rename "$pcfile.new", $pcfile or die "Cannot rename $pcfile.new to $pcfile - $!";
+         unlink $pcfile;
       }
    }
 
@@ -236,6 +361,34 @@ sub ACTION_test
    $self->make_in_srcdir( "test" );
 }
 
+sub ACTION_install
+{
+   my $self = shift;
+   $self->SUPER::ACTION_install;
+
+   return unless $self->notes( 'use_bundled' );
+
+   my $pkgconfig_module = $self->pkgconfig_module;
+   my $libdir = $self->install_destination( "arch" );
+
+   my $pcfile = "$libdir/pkgconfig/$pkgconfig_module.pc";
+   return unless -f "$pcfile.PL";
+
+   open my $out, ">", $pcfile or die "Unable to open $pcfile for writing - $!";
+
+   defined( my $kid = fork() ) or die "Unable to fork - $!";
+   if( $kid == 0 ) {
+      close STDOUT;
+      open STDOUT, ">&", $out or die "Unable to reopen $out - $!";
+
+      exec $^X, "$pcfile.PL" or
+         die "exec() failed - $!";
+   }
+
+   waitpid $kid, 0;
+   die "Child failed - $?" if $?;
+}
+
 sub ACTION_clean
 {
    my $self = shift;
