@@ -1,27 +1,7 @@
 #include <unibilium.h>
-#include <stdio.h>
 #include <errno.h>
 #include <string.h>
-#include <stdlib.h>
-
-static unsigned test_counter;
-
-static void plan(unsigned n) {
-    printf("1..%u\n", n);
-}
-
-static void ok(int b, const char *s) {
-    printf("%sok %u - %s\n", b ? "" : "not ", test_counter++, s);
-}
-
-static void bail_out(const char *s) {
-    printf("Bail out! %s\n", s);
-    exit(EXIT_FAILURE);
-}
-
-static void diag(const char *s) {
-    printf("# %s\n", s);
-}
+#include "test-simple.c.inc"
 
 const char terminfo[] = {
     26, 1, 42, 0, 43, 0, 15, 0, 105, 1, 106, 2, 115, 99, 114, 101, 101, 110, 124, 86,
@@ -108,10 +88,12 @@ const char terminfo[] = {
 static void setup(void);
 
 int main(void) {
+    int e;
+    unibi_term *dt;
+
     setup();
 
-    int e;
-    unibi_term *dt = unibi_dummy();
+    dt = unibi_dummy();
     e = errno;
     ok(dt != NULL, "dummy constructed");
     if (!dt) {
@@ -124,18 +106,18 @@ int main(void) {
         bail_out(strerror(e));
     }
 
-    diag("terminal name");
-    ok(strcmp(unibi_get_name(ut), "VT 100/ANSI X3.64 virtual terminal") == 0, "terminal name = \"VT 100/ANSI X3.64 virtual terminal\"");
+    note("terminal name");
+    ok(strcmp(unibi_get_name(ut), "VT 100/ANSI X3.64 virtual terminal") == 0, "terminal name = \"%s\"", "VT 100/ANSI X3.64 virtual terminal");
     unibi_set_name(dt, "VT 100/ANSI X3.64 virtual terminal");
     {
         static const char *def_aliases[] = {"screen", NULL};
         const char **aliases = unibi_get_aliases(ut);
-        ok(strcmp(aliases[0], def_aliases[0]) == 0, "terminal alias #0 = \"screen\"");
+        ok(strcmp(aliases[0], def_aliases[0]) == 0, "terminal alias #0 = \"%s\"", "screen");
         ok(aliases[1] == NULL, "terminal alias #1 = null");
         unibi_set_aliases(dt, def_aliases);
     }
 
-    diag("boolean capabilities");
+    note("boolean capabilities");
     ok(unibi_get_bool(ut, unibi_auto_left_margin) == 0, "auto_left_margin = false");
     ok(unibi_get_bool(ut, unibi_auto_right_margin) == 1, "auto_right_margin = true");
     unibi_set_bool(dt, unibi_auto_right_margin, 1);
@@ -188,7 +170,7 @@ int main(void) {
     unibi_set_bool(dt, unibi_has_hardware_tabs, 1);
     ok(unibi_get_bool(ut, unibi_return_does_clr_eol) == 0, "return_does_clr_eol = false");
 
-    diag("numeric capabilities");
+    note("numeric capabilities");
     ok(unibi_get_num(ut, unibi_columns) == 80, "columns = 80");
     unibi_set_num(dt, unibi_columns, 80);
     ok(unibi_get_num(ut, unibi_init_tabs) == 8, "init_tabs = 8");
@@ -234,154 +216,154 @@ int main(void) {
     ok(unibi_get_num(ut, unibi_horizontal_tab_delay) == -1, "horizontal_tab_delay = -1");
     ok(unibi_get_num(ut, unibi_number_of_function_keys) == -1, "number_of_function_keys = -1");
 
-    diag("string capabilities");
-    ok(strcmp(unibi_get_str(ut, unibi_back_tab), "\033[Z") == 0, "back_tab = \"\\033[Z\"");
+    note("string capabilities");
+    ok(strcmp(unibi_get_str(ut, unibi_back_tab), "\033[Z") == 0, "back_tab = \"%s\"", "\\033[Z");
     unibi_set_str(dt, unibi_back_tab, "\033[Z");
-    ok(strcmp(unibi_get_str(ut, unibi_bell), "\007") == 0, "bell = \"\\007\"");
+    ok(strcmp(unibi_get_str(ut, unibi_bell), "\007") == 0, "bell = \"%s\"", "\\007");
     unibi_set_str(dt, unibi_bell, "\007");
-    ok(strcmp(unibi_get_str(ut, unibi_carriage_return), "\015") == 0, "carriage_return = \"\\015\"");
+    ok(strcmp(unibi_get_str(ut, unibi_carriage_return), "\015") == 0, "carriage_return = \"%s\"", "\\015");
     unibi_set_str(dt, unibi_carriage_return, "\015");
-    ok(strcmp(unibi_get_str(ut, unibi_change_scroll_region), "\033[%i%p1%d;%p2%dr") == 0, "change_scroll_region = \"\\033[%i%p1%d;%p2%dr\"");
+    ok(strcmp(unibi_get_str(ut, unibi_change_scroll_region), "\033[%i%p1%d;%p2%dr") == 0, "change_scroll_region = \"%s\"", "\\033[%i%p1%d;%p2%dr");
     unibi_set_str(dt, unibi_change_scroll_region, "\033[%i%p1%d;%p2%dr");
-    ok(strcmp(unibi_get_str(ut, unibi_clear_all_tabs), "\033[3g") == 0, "clear_all_tabs = \"\\033[3g\"");
+    ok(strcmp(unibi_get_str(ut, unibi_clear_all_tabs), "\033[3g") == 0, "clear_all_tabs = \"%s\"", "\\033[3g");
     unibi_set_str(dt, unibi_clear_all_tabs, "\033[3g");
-    ok(strcmp(unibi_get_str(ut, unibi_clear_screen), "\033[H\033[J") == 0, "clear_screen = \"\\033[H\\033[J\"");
+    ok(strcmp(unibi_get_str(ut, unibi_clear_screen), "\033[H\033[J") == 0, "clear_screen = \"%s\"", "\\033[H\\033[J");
     unibi_set_str(dt, unibi_clear_screen, "\033[H\033[J");
-    ok(strcmp(unibi_get_str(ut, unibi_clr_eol), "\033[K") == 0, "clr_eol = \"\\033[K\"");
+    ok(strcmp(unibi_get_str(ut, unibi_clr_eol), "\033[K") == 0, "clr_eol = \"%s\"", "\\033[K");
     unibi_set_str(dt, unibi_clr_eol, "\033[K");
-    ok(strcmp(unibi_get_str(ut, unibi_clr_eos), "\033[J") == 0, "clr_eos = \"\\033[J\"");
+    ok(strcmp(unibi_get_str(ut, unibi_clr_eos), "\033[J") == 0, "clr_eos = \"%s\"", "\\033[J");
     unibi_set_str(dt, unibi_clr_eos, "\033[J");
     ok(unibi_get_str(ut, unibi_column_address) == NULL, "column_address = null");
     ok(unibi_get_str(ut, unibi_command_character) == NULL, "command_character = null");
-    ok(strcmp(unibi_get_str(ut, unibi_cursor_address), "\033[%i%p1%d;%p2%dH") == 0, "cursor_address = \"\\033[%i%p1%d;%p2%dH\"");
+    ok(strcmp(unibi_get_str(ut, unibi_cursor_address), "\033[%i%p1%d;%p2%dH") == 0, "cursor_address = \"%s\"", "\\033[%i%p1%d;%p2%dH");
     unibi_set_str(dt, unibi_cursor_address, "\033[%i%p1%d;%p2%dH");
-    ok(strcmp(unibi_get_str(ut, unibi_cursor_down), "\012") == 0, "cursor_down = \"\\012\"");
+    ok(strcmp(unibi_get_str(ut, unibi_cursor_down), "\012") == 0, "cursor_down = \"%s\"", "\\012");
     unibi_set_str(dt, unibi_cursor_down, "\012");
-    ok(strcmp(unibi_get_str(ut, unibi_cursor_home), "\033[H") == 0, "cursor_home = \"\\033[H\"");
+    ok(strcmp(unibi_get_str(ut, unibi_cursor_home), "\033[H") == 0, "cursor_home = \"%s\"", "\\033[H");
     unibi_set_str(dt, unibi_cursor_home, "\033[H");
-    ok(strcmp(unibi_get_str(ut, unibi_cursor_invisible), "\033[?25l") == 0, "cursor_invisible = \"\\033[?25l\"");
+    ok(strcmp(unibi_get_str(ut, unibi_cursor_invisible), "\033[?25l") == 0, "cursor_invisible = \"%s\"", "\\033[?25l");
     unibi_set_str(dt, unibi_cursor_invisible, "\033[?25l");
-    ok(strcmp(unibi_get_str(ut, unibi_cursor_left), "\010") == 0, "cursor_left = \"\\010\"");
+    ok(strcmp(unibi_get_str(ut, unibi_cursor_left), "\010") == 0, "cursor_left = \"%s\"", "\\010");
     unibi_set_str(dt, unibi_cursor_left, "\010");
     ok(unibi_get_str(ut, unibi_cursor_mem_address) == NULL, "cursor_mem_address = null");
-    ok(strcmp(unibi_get_str(ut, unibi_cursor_normal), "\033[34h\033[?25h") == 0, "cursor_normal = \"\\033[34h\\033[?25h\"");
+    ok(strcmp(unibi_get_str(ut, unibi_cursor_normal), "\033[34h\033[?25h") == 0, "cursor_normal = \"%s\"", "\\033[34h\\033[?25h");
     unibi_set_str(dt, unibi_cursor_normal, "\033[34h\033[?25h");
-    ok(strcmp(unibi_get_str(ut, unibi_cursor_right), "\033[C") == 0, "cursor_right = \"\\033[C\"");
+    ok(strcmp(unibi_get_str(ut, unibi_cursor_right), "\033[C") == 0, "cursor_right = \"%s\"", "\\033[C");
     unibi_set_str(dt, unibi_cursor_right, "\033[C");
     ok(unibi_get_str(ut, unibi_cursor_to_ll) == NULL, "cursor_to_ll = null");
-    ok(strcmp(unibi_get_str(ut, unibi_cursor_up), "\033M") == 0, "cursor_up = \"\\033M\"");
+    ok(strcmp(unibi_get_str(ut, unibi_cursor_up), "\033M") == 0, "cursor_up = \"%s\"", "\\033M");
     unibi_set_str(dt, unibi_cursor_up, "\033M");
-    ok(strcmp(unibi_get_str(ut, unibi_cursor_visible), "\033[34l") == 0, "cursor_visible = \"\\033[34l\"");
+    ok(strcmp(unibi_get_str(ut, unibi_cursor_visible), "\033[34l") == 0, "cursor_visible = \"%s\"", "\\033[34l");
     unibi_set_str(dt, unibi_cursor_visible, "\033[34l");
-    ok(strcmp(unibi_get_str(ut, unibi_delete_character), "\033[P") == 0, "delete_character = \"\\033[P\"");
+    ok(strcmp(unibi_get_str(ut, unibi_delete_character), "\033[P") == 0, "delete_character = \"%s\"", "\\033[P");
     unibi_set_str(dt, unibi_delete_character, "\033[P");
-    ok(strcmp(unibi_get_str(ut, unibi_delete_line), "\033[M") == 0, "delete_line = \"\\033[M\"");
+    ok(strcmp(unibi_get_str(ut, unibi_delete_line), "\033[M") == 0, "delete_line = \"%s\"", "\\033[M");
     unibi_set_str(dt, unibi_delete_line, "\033[M");
     ok(unibi_get_str(ut, unibi_dis_status_line) == NULL, "dis_status_line = null");
     ok(unibi_get_str(ut, unibi_down_half_line) == NULL, "down_half_line = null");
-    ok(strcmp(unibi_get_str(ut, unibi_enter_alt_charset_mode), "\016") == 0, "enter_alt_charset_mode = \"\\016\"");
+    ok(strcmp(unibi_get_str(ut, unibi_enter_alt_charset_mode), "\016") == 0, "enter_alt_charset_mode = \"%s\"", "\\016");
     unibi_set_str(dt, unibi_enter_alt_charset_mode, "\016");
-    ok(strcmp(unibi_get_str(ut, unibi_enter_blink_mode), "\033[5m") == 0, "enter_blink_mode = \"\\033[5m\"");
+    ok(strcmp(unibi_get_str(ut, unibi_enter_blink_mode), "\033[5m") == 0, "enter_blink_mode = \"%s\"", "\\033[5m");
     unibi_set_str(dt, unibi_enter_blink_mode, "\033[5m");
-    ok(strcmp(unibi_get_str(ut, unibi_enter_bold_mode), "\033[1m") == 0, "enter_bold_mode = \"\\033[1m\"");
+    ok(strcmp(unibi_get_str(ut, unibi_enter_bold_mode), "\033[1m") == 0, "enter_bold_mode = \"%s\"", "\\033[1m");
     unibi_set_str(dt, unibi_enter_bold_mode, "\033[1m");
-    ok(strcmp(unibi_get_str(ut, unibi_enter_ca_mode), "\033[?1049h") == 0, "enter_ca_mode = \"\\033[?1049h\"");
+    ok(strcmp(unibi_get_str(ut, unibi_enter_ca_mode), "\033[?1049h") == 0, "enter_ca_mode = \"%s\"", "\\033[?1049h");
     unibi_set_str(dt, unibi_enter_ca_mode, "\033[?1049h");
     ok(unibi_get_str(ut, unibi_enter_delete_mode) == NULL, "enter_delete_mode = null");
     ok(unibi_get_str(ut, unibi_enter_dim_mode) == NULL, "enter_dim_mode = null");
-    ok(strcmp(unibi_get_str(ut, unibi_enter_insert_mode), "\033[4h") == 0, "enter_insert_mode = \"\\033[4h\"");
+    ok(strcmp(unibi_get_str(ut, unibi_enter_insert_mode), "\033[4h") == 0, "enter_insert_mode = \"%s\"", "\\033[4h");
     unibi_set_str(dt, unibi_enter_insert_mode, "\033[4h");
     ok(unibi_get_str(ut, unibi_enter_secure_mode) == NULL, "enter_secure_mode = null");
     ok(unibi_get_str(ut, unibi_enter_protected_mode) == NULL, "enter_protected_mode = null");
-    ok(strcmp(unibi_get_str(ut, unibi_enter_reverse_mode), "\033[7m") == 0, "enter_reverse_mode = \"\\033[7m\"");
+    ok(strcmp(unibi_get_str(ut, unibi_enter_reverse_mode), "\033[7m") == 0, "enter_reverse_mode = \"%s\"", "\\033[7m");
     unibi_set_str(dt, unibi_enter_reverse_mode, "\033[7m");
-    ok(strcmp(unibi_get_str(ut, unibi_enter_standout_mode), "\033[3m") == 0, "enter_standout_mode = \"\\033[3m\"");
+    ok(strcmp(unibi_get_str(ut, unibi_enter_standout_mode), "\033[3m") == 0, "enter_standout_mode = \"%s\"", "\\033[3m");
     unibi_set_str(dt, unibi_enter_standout_mode, "\033[3m");
-    ok(strcmp(unibi_get_str(ut, unibi_enter_underline_mode), "\033[4m") == 0, "enter_underline_mode = \"\\033[4m\"");
+    ok(strcmp(unibi_get_str(ut, unibi_enter_underline_mode), "\033[4m") == 0, "enter_underline_mode = \"%s\"", "\\033[4m");
     unibi_set_str(dt, unibi_enter_underline_mode, "\033[4m");
     ok(unibi_get_str(ut, unibi_erase_chars) == NULL, "erase_chars = null");
-    ok(strcmp(unibi_get_str(ut, unibi_exit_alt_charset_mode), "\017") == 0, "exit_alt_charset_mode = \"\\017\"");
+    ok(strcmp(unibi_get_str(ut, unibi_exit_alt_charset_mode), "\017") == 0, "exit_alt_charset_mode = \"%s\"", "\\017");
     unibi_set_str(dt, unibi_exit_alt_charset_mode, "\017");
-    ok(strcmp(unibi_get_str(ut, unibi_exit_attribute_mode), "\033[m\017") == 0, "exit_attribute_mode = \"\\033[m\\017\"");
+    ok(strcmp(unibi_get_str(ut, unibi_exit_attribute_mode), "\033[m\017") == 0, "exit_attribute_mode = \"%s\"", "\\033[m\\017");
     unibi_set_str(dt, unibi_exit_attribute_mode, "\033[m\017");
-    ok(strcmp(unibi_get_str(ut, unibi_exit_ca_mode), "\033[?1049l") == 0, "exit_ca_mode = \"\\033[?1049l\"");
+    ok(strcmp(unibi_get_str(ut, unibi_exit_ca_mode), "\033[?1049l") == 0, "exit_ca_mode = \"%s\"", "\\033[?1049l");
     unibi_set_str(dt, unibi_exit_ca_mode, "\033[?1049l");
     ok(unibi_get_str(ut, unibi_exit_delete_mode) == NULL, "exit_delete_mode = null");
-    ok(strcmp(unibi_get_str(ut, unibi_exit_insert_mode), "\033[4l") == 0, "exit_insert_mode = \"\\033[4l\"");
+    ok(strcmp(unibi_get_str(ut, unibi_exit_insert_mode), "\033[4l") == 0, "exit_insert_mode = \"%s\"", "\\033[4l");
     unibi_set_str(dt, unibi_exit_insert_mode, "\033[4l");
-    ok(strcmp(unibi_get_str(ut, unibi_exit_standout_mode), "\033[23m") == 0, "exit_standout_mode = \"\\033[23m\"");
+    ok(strcmp(unibi_get_str(ut, unibi_exit_standout_mode), "\033[23m") == 0, "exit_standout_mode = \"%s\"", "\\033[23m");
     unibi_set_str(dt, unibi_exit_standout_mode, "\033[23m");
-    ok(strcmp(unibi_get_str(ut, unibi_exit_underline_mode), "\033[24m") == 0, "exit_underline_mode = \"\\033[24m\"");
+    ok(strcmp(unibi_get_str(ut, unibi_exit_underline_mode), "\033[24m") == 0, "exit_underline_mode = \"%s\"", "\\033[24m");
     unibi_set_str(dt, unibi_exit_underline_mode, "\033[24m");
-    ok(strcmp(unibi_get_str(ut, unibi_flash_screen), "\033g") == 0, "flash_screen = \"\\033g\"");
+    ok(strcmp(unibi_get_str(ut, unibi_flash_screen), "\033g") == 0, "flash_screen = \"%s\"", "\\033g");
     unibi_set_str(dt, unibi_flash_screen, "\033g");
     ok(unibi_get_str(ut, unibi_form_feed) == NULL, "form_feed = null");
     ok(unibi_get_str(ut, unibi_from_status_line) == NULL, "from_status_line = null");
     ok(unibi_get_str(ut, unibi_init_1string) == NULL, "init_1string = null");
-    ok(strcmp(unibi_get_str(ut, unibi_init_2string), "\033)0") == 0, "init_2string = \"\\033)0\"");
+    ok(strcmp(unibi_get_str(ut, unibi_init_2string), "\033)0") == 0, "init_2string = \"%s\"", "\\033)0");
     unibi_set_str(dt, unibi_init_2string, "\033)0");
     ok(unibi_get_str(ut, unibi_init_3string) == NULL, "init_3string = null");
     ok(unibi_get_str(ut, unibi_init_file) == NULL, "init_file = null");
     ok(unibi_get_str(ut, unibi_insert_character) == NULL, "insert_character = null");
-    ok(strcmp(unibi_get_str(ut, unibi_insert_line), "\033[L") == 0, "insert_line = \"\\033[L\"");
+    ok(strcmp(unibi_get_str(ut, unibi_insert_line), "\033[L") == 0, "insert_line = \"%s\"", "\\033[L");
     unibi_set_str(dt, unibi_insert_line, "\033[L");
     ok(unibi_get_str(ut, unibi_insert_padding) == NULL, "insert_padding = null");
-    ok(strcmp(unibi_get_str(ut, unibi_key_backspace), "\010") == 0, "key_backspace = \"\\010\"");
+    ok(strcmp(unibi_get_str(ut, unibi_key_backspace), "\010") == 0, "key_backspace = \"%s\"", "\\010");
     unibi_set_str(dt, unibi_key_backspace, "\010");
     ok(unibi_get_str(ut, unibi_key_catab) == NULL, "key_catab = null");
     ok(unibi_get_str(ut, unibi_key_clear) == NULL, "key_clear = null");
     ok(unibi_get_str(ut, unibi_key_ctab) == NULL, "key_ctab = null");
-    ok(strcmp(unibi_get_str(ut, unibi_key_dc), "\033[3~") == 0, "key_dc = \"\\033[3~\"");
+    ok(strcmp(unibi_get_str(ut, unibi_key_dc), "\033[3~") == 0, "key_dc = \"%s\"", "\\033[3~");
     unibi_set_str(dt, unibi_key_dc, "\033[3~");
     ok(unibi_get_str(ut, unibi_key_dl) == NULL, "key_dl = null");
-    ok(strcmp(unibi_get_str(ut, unibi_key_down), "\033OB") == 0, "key_down = \"\\033OB\"");
+    ok(strcmp(unibi_get_str(ut, unibi_key_down), "\033OB") == 0, "key_down = \"%s\"", "\\033OB");
     unibi_set_str(dt, unibi_key_down, "\033OB");
     ok(unibi_get_str(ut, unibi_key_eic) == NULL, "key_eic = null");
     ok(unibi_get_str(ut, unibi_key_eol) == NULL, "key_eol = null");
     ok(unibi_get_str(ut, unibi_key_eos) == NULL, "key_eos = null");
     ok(unibi_get_str(ut, unibi_key_f0) == NULL, "key_f0 = null");
-    ok(strcmp(unibi_get_str(ut, unibi_key_f1), "\033OP") == 0, "key_f1 = \"\\033OP\"");
+    ok(strcmp(unibi_get_str(ut, unibi_key_f1), "\033OP") == 0, "key_f1 = \"%s\"", "\\033OP");
     unibi_set_str(dt, unibi_key_f1, "\033OP");
-    ok(strcmp(unibi_get_str(ut, unibi_key_f10), "\033[21~") == 0, "key_f10 = \"\\033[21~\"");
+    ok(strcmp(unibi_get_str(ut, unibi_key_f10), "\033[21~") == 0, "key_f10 = \"%s\"", "\\033[21~");
     unibi_set_str(dt, unibi_key_f10, "\033[21~");
-    ok(strcmp(unibi_get_str(ut, unibi_key_f2), "\033OQ") == 0, "key_f2 = \"\\033OQ\"");
+    ok(strcmp(unibi_get_str(ut, unibi_key_f2), "\033OQ") == 0, "key_f2 = \"%s\"", "\\033OQ");
     unibi_set_str(dt, unibi_key_f2, "\033OQ");
-    ok(strcmp(unibi_get_str(ut, unibi_key_f3), "\033OR") == 0, "key_f3 = \"\\033OR\"");
+    ok(strcmp(unibi_get_str(ut, unibi_key_f3), "\033OR") == 0, "key_f3 = \"%s\"", "\\033OR");
     unibi_set_str(dt, unibi_key_f3, "\033OR");
-    ok(strcmp(unibi_get_str(ut, unibi_key_f4), "\033OS") == 0, "key_f4 = \"\\033OS\"");
+    ok(strcmp(unibi_get_str(ut, unibi_key_f4), "\033OS") == 0, "key_f4 = \"%s\"", "\\033OS");
     unibi_set_str(dt, unibi_key_f4, "\033OS");
-    ok(strcmp(unibi_get_str(ut, unibi_key_f5), "\033[15~") == 0, "key_f5 = \"\\033[15~\"");
+    ok(strcmp(unibi_get_str(ut, unibi_key_f5), "\033[15~") == 0, "key_f5 = \"%s\"", "\\033[15~");
     unibi_set_str(dt, unibi_key_f5, "\033[15~");
-    ok(strcmp(unibi_get_str(ut, unibi_key_f6), "\033[17~") == 0, "key_f6 = \"\\033[17~\"");
+    ok(strcmp(unibi_get_str(ut, unibi_key_f6), "\033[17~") == 0, "key_f6 = \"%s\"", "\\033[17~");
     unibi_set_str(dt, unibi_key_f6, "\033[17~");
-    ok(strcmp(unibi_get_str(ut, unibi_key_f7), "\033[18~") == 0, "key_f7 = \"\\033[18~\"");
+    ok(strcmp(unibi_get_str(ut, unibi_key_f7), "\033[18~") == 0, "key_f7 = \"%s\"", "\\033[18~");
     unibi_set_str(dt, unibi_key_f7, "\033[18~");
-    ok(strcmp(unibi_get_str(ut, unibi_key_f8), "\033[19~") == 0, "key_f8 = \"\\033[19~\"");
+    ok(strcmp(unibi_get_str(ut, unibi_key_f8), "\033[19~") == 0, "key_f8 = \"%s\"", "\\033[19~");
     unibi_set_str(dt, unibi_key_f8, "\033[19~");
-    ok(strcmp(unibi_get_str(ut, unibi_key_f9), "\033[20~") == 0, "key_f9 = \"\\033[20~\"");
+    ok(strcmp(unibi_get_str(ut, unibi_key_f9), "\033[20~") == 0, "key_f9 = \"%s\"", "\\033[20~");
     unibi_set_str(dt, unibi_key_f9, "\033[20~");
-    ok(strcmp(unibi_get_str(ut, unibi_key_home), "\033[1~") == 0, "key_home = \"\\033[1~\"");
+    ok(strcmp(unibi_get_str(ut, unibi_key_home), "\033[1~") == 0, "key_home = \"%s\"", "\\033[1~");
     unibi_set_str(dt, unibi_key_home, "\033[1~");
-    ok(strcmp(unibi_get_str(ut, unibi_key_ic), "\033[2~") == 0, "key_ic = \"\\033[2~\"");
+    ok(strcmp(unibi_get_str(ut, unibi_key_ic), "\033[2~") == 0, "key_ic = \"%s\"", "\\033[2~");
     unibi_set_str(dt, unibi_key_ic, "\033[2~");
     ok(unibi_get_str(ut, unibi_key_il) == NULL, "key_il = null");
-    ok(strcmp(unibi_get_str(ut, unibi_key_left), "\033OD") == 0, "key_left = \"\\033OD\"");
+    ok(strcmp(unibi_get_str(ut, unibi_key_left), "\033OD") == 0, "key_left = \"%s\"", "\\033OD");
     unibi_set_str(dt, unibi_key_left, "\033OD");
     ok(unibi_get_str(ut, unibi_key_ll) == NULL, "key_ll = null");
-    ok(strcmp(unibi_get_str(ut, unibi_key_npage), "\033[6~") == 0, "key_npage = \"\\033[6~\"");
+    ok(strcmp(unibi_get_str(ut, unibi_key_npage), "\033[6~") == 0, "key_npage = \"%s\"", "\\033[6~");
     unibi_set_str(dt, unibi_key_npage, "\033[6~");
-    ok(strcmp(unibi_get_str(ut, unibi_key_ppage), "\033[5~") == 0, "key_ppage = \"\\033[5~\"");
+    ok(strcmp(unibi_get_str(ut, unibi_key_ppage), "\033[5~") == 0, "key_ppage = \"%s\"", "\\033[5~");
     unibi_set_str(dt, unibi_key_ppage, "\033[5~");
-    ok(strcmp(unibi_get_str(ut, unibi_key_right), "\033OC") == 0, "key_right = \"\\033OC\"");
+    ok(strcmp(unibi_get_str(ut, unibi_key_right), "\033OC") == 0, "key_right = \"%s\"", "\\033OC");
     unibi_set_str(dt, unibi_key_right, "\033OC");
     ok(unibi_get_str(ut, unibi_key_sf) == NULL, "key_sf = null");
     ok(unibi_get_str(ut, unibi_key_sr) == NULL, "key_sr = null");
     ok(unibi_get_str(ut, unibi_key_stab) == NULL, "key_stab = null");
-    ok(strcmp(unibi_get_str(ut, unibi_key_up), "\033OA") == 0, "key_up = \"\\033OA\"");
+    ok(strcmp(unibi_get_str(ut, unibi_key_up), "\033OA") == 0, "key_up = \"%s\"", "\\033OA");
     unibi_set_str(dt, unibi_key_up, "\033OA");
-    ok(strcmp(unibi_get_str(ut, unibi_keypad_local), "\033[?1l\033>") == 0, "keypad_local = \"\\033[?1l\\033>\"");
+    ok(strcmp(unibi_get_str(ut, unibi_keypad_local), "\033[?1l\033>") == 0, "keypad_local = \"%s\"", "\\033[?1l\\033>");
     unibi_set_str(dt, unibi_keypad_local, "\033[?1l\033>");
-    ok(strcmp(unibi_get_str(ut, unibi_keypad_xmit), "\033[?1h\033=") == 0, "keypad_xmit = \"\\033[?1h\\033=\"");
+    ok(strcmp(unibi_get_str(ut, unibi_keypad_xmit), "\033[?1h\033=") == 0, "keypad_xmit = \"%s\"", "\\033[?1h\\033=");
     unibi_set_str(dt, unibi_keypad_xmit, "\033[?1h\033=");
     ok(unibi_get_str(ut, unibi_lab_f0) == NULL, "lab_f0 = null");
     ok(unibi_get_str(ut, unibi_lab_f1) == NULL, "lab_f1 = null");
@@ -396,26 +378,26 @@ int main(void) {
     ok(unibi_get_str(ut, unibi_lab_f9) == NULL, "lab_f9 = null");
     ok(unibi_get_str(ut, unibi_meta_off) == NULL, "meta_off = null");
     ok(unibi_get_str(ut, unibi_meta_on) == NULL, "meta_on = null");
-    ok(strcmp(unibi_get_str(ut, unibi_newline), "\033E") == 0, "newline = \"\\033E\"");
+    ok(strcmp(unibi_get_str(ut, unibi_newline), "\033E") == 0, "newline = \"%s\"", "\\033E");
     unibi_set_str(dt, unibi_newline, "\033E");
     ok(unibi_get_str(ut, unibi_pad_char) == NULL, "pad_char = null");
-    ok(strcmp(unibi_get_str(ut, unibi_parm_dch), "\033[%p1%dP") == 0, "parm_dch = \"\\033[%p1%dP\"");
+    ok(strcmp(unibi_get_str(ut, unibi_parm_dch), "\033[%p1%dP") == 0, "parm_dch = \"%s\"", "\\033[%p1%dP");
     unibi_set_str(dt, unibi_parm_dch, "\033[%p1%dP");
-    ok(strcmp(unibi_get_str(ut, unibi_parm_delete_line), "\033[%p1%dM") == 0, "parm_delete_line = \"\\033[%p1%dM\"");
+    ok(strcmp(unibi_get_str(ut, unibi_parm_delete_line), "\033[%p1%dM") == 0, "parm_delete_line = \"%s\"", "\\033[%p1%dM");
     unibi_set_str(dt, unibi_parm_delete_line, "\033[%p1%dM");
-    ok(strcmp(unibi_get_str(ut, unibi_parm_down_cursor), "\033[%p1%dB") == 0, "parm_down_cursor = \"\\033[%p1%dB\"");
+    ok(strcmp(unibi_get_str(ut, unibi_parm_down_cursor), "\033[%p1%dB") == 0, "parm_down_cursor = \"%s\"", "\\033[%p1%dB");
     unibi_set_str(dt, unibi_parm_down_cursor, "\033[%p1%dB");
-    ok(strcmp(unibi_get_str(ut, unibi_parm_ich), "\033[%p1%d@") == 0, "parm_ich = \"\\033[%p1%d@\"");
+    ok(strcmp(unibi_get_str(ut, unibi_parm_ich), "\033[%p1%d@") == 0, "parm_ich = \"%s\"", "\\033[%p1%d@");
     unibi_set_str(dt, unibi_parm_ich, "\033[%p1%d@");
     ok(unibi_get_str(ut, unibi_parm_index) == NULL, "parm_index = null");
-    ok(strcmp(unibi_get_str(ut, unibi_parm_insert_line), "\033[%p1%dL") == 0, "parm_insert_line = \"\\033[%p1%dL\"");
+    ok(strcmp(unibi_get_str(ut, unibi_parm_insert_line), "\033[%p1%dL") == 0, "parm_insert_line = \"%s\"", "\\033[%p1%dL");
     unibi_set_str(dt, unibi_parm_insert_line, "\033[%p1%dL");
-    ok(strcmp(unibi_get_str(ut, unibi_parm_left_cursor), "\033[%p1%dD") == 0, "parm_left_cursor = \"\\033[%p1%dD\"");
+    ok(strcmp(unibi_get_str(ut, unibi_parm_left_cursor), "\033[%p1%dD") == 0, "parm_left_cursor = \"%s\"", "\\033[%p1%dD");
     unibi_set_str(dt, unibi_parm_left_cursor, "\033[%p1%dD");
-    ok(strcmp(unibi_get_str(ut, unibi_parm_right_cursor), "\033[%p1%dC") == 0, "parm_right_cursor = \"\\033[%p1%dC\"");
+    ok(strcmp(unibi_get_str(ut, unibi_parm_right_cursor), "\033[%p1%dC") == 0, "parm_right_cursor = \"%s\"", "\\033[%p1%dC");
     unibi_set_str(dt, unibi_parm_right_cursor, "\033[%p1%dC");
     ok(unibi_get_str(ut, unibi_parm_rindex) == NULL, "parm_rindex = null");
-    ok(strcmp(unibi_get_str(ut, unibi_parm_up_cursor), "\033[%p1%dA") == 0, "parm_up_cursor = \"\\033[%p1%dA\"");
+    ok(strcmp(unibi_get_str(ut, unibi_parm_up_cursor), "\033[%p1%dA") == 0, "parm_up_cursor = \"%s\"", "\\033[%p1%dA");
     unibi_set_str(dt, unibi_parm_up_cursor, "\033[%p1%dA");
     ok(unibi_get_str(ut, unibi_pkey_key) == NULL, "pkey_key = null");
     ok(unibi_get_str(ut, unibi_pkey_local) == NULL, "pkey_local = null");
@@ -425,25 +407,25 @@ int main(void) {
     ok(unibi_get_str(ut, unibi_prtr_on) == NULL, "prtr_on = null");
     ok(unibi_get_str(ut, unibi_repeat_char) == NULL, "repeat_char = null");
     ok(unibi_get_str(ut, unibi_reset_1string) == NULL, "reset_1string = null");
-    ok(strcmp(unibi_get_str(ut, unibi_reset_2string), "\033c\033[?1000l\033[?25h") == 0, "reset_2string = \"\\033c\\033[?1000l\\033[?25h\"");
+    ok(strcmp(unibi_get_str(ut, unibi_reset_2string), "\033c\033[?1000l\033[?25h") == 0, "reset_2string = \"%s\"", "\\033c\\033[?1000l\\033[?25h");
     unibi_set_str(dt, unibi_reset_2string, "\033c\033[?1000l\033[?25h");
     ok(unibi_get_str(ut, unibi_reset_3string) == NULL, "reset_3string = null");
     ok(unibi_get_str(ut, unibi_reset_file) == NULL, "reset_file = null");
-    ok(strcmp(unibi_get_str(ut, unibi_restore_cursor), "\0338") == 0, "restore_cursor = \"\\0338\"");
+    ok(strcmp(unibi_get_str(ut, unibi_restore_cursor), "\0338") == 0, "restore_cursor = \"%s\"", "\\0338");
     unibi_set_str(dt, unibi_restore_cursor, "\0338");
     ok(unibi_get_str(ut, unibi_row_address) == NULL, "row_address = null");
-    ok(strcmp(unibi_get_str(ut, unibi_save_cursor), "\0337") == 0, "save_cursor = \"\\0337\"");
+    ok(strcmp(unibi_get_str(ut, unibi_save_cursor), "\0337") == 0, "save_cursor = \"%s\"", "\\0337");
     unibi_set_str(dt, unibi_save_cursor, "\0337");
-    ok(strcmp(unibi_get_str(ut, unibi_scroll_forward), "\012") == 0, "scroll_forward = \"\\012\"");
+    ok(strcmp(unibi_get_str(ut, unibi_scroll_forward), "\012") == 0, "scroll_forward = \"%s\"", "\\012");
     unibi_set_str(dt, unibi_scroll_forward, "\012");
-    ok(strcmp(unibi_get_str(ut, unibi_scroll_reverse), "\033M") == 0, "scroll_reverse = \"\\033M\"");
+    ok(strcmp(unibi_get_str(ut, unibi_scroll_reverse), "\033M") == 0, "scroll_reverse = \"%s\"", "\\033M");
     unibi_set_str(dt, unibi_scroll_reverse, "\033M");
-    ok(strcmp(unibi_get_str(ut, unibi_set_attributes), "\033[0%?%p6%t;1%;%?%p1%t;3%;%?%p2%t;4%;%?%p3%t;7%;%?%p4%t;5%;m%?%p9%t\016%e\017%;") == 0, "set_attributes = \"\\033[0%?%p6%t;1%;%?%p1%t;3%;%?%p2%t;4%;%?%p3%t;7%;%?%p4%t;5%;m%?%p9%t\\016%e\\017%;\"");
+    ok(strcmp(unibi_get_str(ut, unibi_set_attributes), "\033[0%?%p6%t;1%;%?%p1%t;3%;%?%p2%t;4%;%?%p3%t;7%;%?%p4%t;5%;m%?%p9%t\016%e\017%;") == 0, "set_attributes = \"%s\"", "\\033[0%?%p6%t;1%;%?%p1%t;3%;%?%p2%t;4%;%?%p3%t;7%;%?%p4%t;5%;m%?%p9%t\\016%e\\017%;");
     unibi_set_str(dt, unibi_set_attributes, "\033[0%?%p6%t;1%;%?%p1%t;3%;%?%p2%t;4%;%?%p3%t;7%;%?%p4%t;5%;m%?%p9%t\016%e\017%;");
-    ok(strcmp(unibi_get_str(ut, unibi_set_tab), "\033H") == 0, "set_tab = \"\\033H\"");
+    ok(strcmp(unibi_get_str(ut, unibi_set_tab), "\033H") == 0, "set_tab = \"%s\"", "\\033H");
     unibi_set_str(dt, unibi_set_tab, "\033H");
     ok(unibi_get_str(ut, unibi_set_window) == NULL, "set_window = null");
-    ok(strcmp(unibi_get_str(ut, unibi_tab), "\011") == 0, "tab = \"\\011\"");
+    ok(strcmp(unibi_get_str(ut, unibi_tab), "\011") == 0, "tab = \"%s\"", "\\011");
     unibi_set_str(dt, unibi_tab, "\011");
     ok(unibi_get_str(ut, unibi_to_status_line) == NULL, "to_status_line = null");
     ok(unibi_get_str(ut, unibi_underline_char) == NULL, "underline_char = null");
@@ -456,10 +438,10 @@ int main(void) {
     ok(unibi_get_str(ut, unibi_key_c3) == NULL, "key_c3 = null");
     ok(unibi_get_str(ut, unibi_prtr_non) == NULL, "prtr_non = null");
     ok(unibi_get_str(ut, unibi_char_padding) == NULL, "char_padding = null");
-    ok(strcmp(unibi_get_str(ut, unibi_acs_chars), "++,,--..00``aaffgghhiijjkkllmmnnooppqqrrssttuuvvwwxxyyzz{{||}}~~") == 0, "acs_chars = \"++,,--..00``aaffgghhiijjkkllmmnnooppqqrrssttuuvvwwxxyyzz{{||}}~~\"");
+    ok(strcmp(unibi_get_str(ut, unibi_acs_chars), "++,,--..00``aaffgghhiijjkkllmmnnooppqqrrssttuuvvwwxxyyzz{{||}}~~") == 0, "acs_chars = \"%s\"", "++,,--..00``aaffgghhiijjkkllmmnnooppqqrrssttuuvvwwxxyyzz{{||}}~~");
     unibi_set_str(dt, unibi_acs_chars, "++,,--..00``aaffgghhiijjkkllmmnnooppqqrrssttuuvvwwxxyyzz{{||}}~~");
     ok(unibi_get_str(ut, unibi_plab_norm) == NULL, "plab_norm = null");
-    ok(strcmp(unibi_get_str(ut, unibi_key_btab), "\033[Z") == 0, "key_btab = \"\\033[Z\"");
+    ok(strcmp(unibi_get_str(ut, unibi_key_btab), "\033[Z") == 0, "key_btab = \"%s\"", "\\033[Z");
     unibi_set_str(dt, unibi_key_btab, "\033[Z");
     ok(unibi_get_str(ut, unibi_enter_xon_mode) == NULL, "enter_xon_mode = null");
     ok(unibi_get_str(ut, unibi_exit_xon_mode) == NULL, "exit_xon_mode = null");
@@ -467,7 +449,7 @@ int main(void) {
     ok(unibi_get_str(ut, unibi_exit_am_mode) == NULL, "exit_am_mode = null");
     ok(unibi_get_str(ut, unibi_xon_character) == NULL, "xon_character = null");
     ok(unibi_get_str(ut, unibi_xoff_character) == NULL, "xoff_character = null");
-    ok(strcmp(unibi_get_str(ut, unibi_ena_acs), "\033(B\033)0") == 0, "ena_acs = \"\\033(B\\033)0\"");
+    ok(strcmp(unibi_get_str(ut, unibi_ena_acs), "\033(B\033)0") == 0, "ena_acs = \"%s\"", "\\033(B\\033)0");
     unibi_set_str(dt, unibi_ena_acs, "\033(B\033)0");
     ok(unibi_get_str(ut, unibi_label_on) == NULL, "label_on = null");
     ok(unibi_get_str(ut, unibi_label_off) == NULL, "label_off = null");
@@ -477,7 +459,7 @@ int main(void) {
     ok(unibi_get_str(ut, unibi_key_command) == NULL, "key_command = null");
     ok(unibi_get_str(ut, unibi_key_copy) == NULL, "key_copy = null");
     ok(unibi_get_str(ut, unibi_key_create) == NULL, "key_create = null");
-    ok(strcmp(unibi_get_str(ut, unibi_key_end), "\033[4~") == 0, "key_end = \"\\033[4~\"");
+    ok(strcmp(unibi_get_str(ut, unibi_key_end), "\033[4~") == 0, "key_end = \"%s\"", "\\033[4~");
     unibi_set_str(dt, unibi_key_end, "\033[4~");
     ok(unibi_get_str(ut, unibi_key_enter) == NULL, "key_enter = null");
     ok(unibi_get_str(ut, unibi_key_exit) == NULL, "key_exit = null");
@@ -530,9 +512,9 @@ int main(void) {
     ok(unibi_get_str(ut, unibi_key_ssuspend) == NULL, "key_ssuspend = null");
     ok(unibi_get_str(ut, unibi_key_sundo) == NULL, "key_sundo = null");
     ok(unibi_get_str(ut, unibi_req_for_input) == NULL, "req_for_input = null");
-    ok(strcmp(unibi_get_str(ut, unibi_key_f11), "\033[23~") == 0, "key_f11 = \"\\033[23~\"");
+    ok(strcmp(unibi_get_str(ut, unibi_key_f11), "\033[23~") == 0, "key_f11 = \"%s\"", "\\033[23~");
     unibi_set_str(dt, unibi_key_f11, "\033[23~");
-    ok(strcmp(unibi_get_str(ut, unibi_key_f12), "\033[24~") == 0, "key_f12 = \"\\033[24~\"");
+    ok(strcmp(unibi_get_str(ut, unibi_key_f12), "\033[24~") == 0, "key_f12 = \"%s\"", "\\033[24~");
     unibi_set_str(dt, unibi_key_f12, "\033[24~");
     ok(unibi_get_str(ut, unibi_key_f13) == NULL, "key_f13 = null");
     ok(unibi_get_str(ut, unibi_key_f14) == NULL, "key_f14 = null");
@@ -585,7 +567,7 @@ int main(void) {
     ok(unibi_get_str(ut, unibi_key_f61) == NULL, "key_f61 = null");
     ok(unibi_get_str(ut, unibi_key_f62) == NULL, "key_f62 = null");
     ok(unibi_get_str(ut, unibi_key_f63) == NULL, "key_f63 = null");
-    ok(strcmp(unibi_get_str(ut, unibi_clr_bol), "\033[1K") == 0, "clr_bol = \"\\033[1K\"");
+    ok(strcmp(unibi_get_str(ut, unibi_clr_bol), "\033[1K") == 0, "clr_bol = \"%s\"", "\\033[1K");
     unibi_set_str(dt, unibi_clr_bol, "\033[1K");
     ok(unibi_get_str(ut, unibi_clear_margins) == NULL, "clear_margins = null");
     ok(unibi_get_str(ut, unibi_set_left_margin) == NULL, "set_left_margin = null");
@@ -614,7 +596,7 @@ int main(void) {
     ok(unibi_get_str(ut, unibi_user7) == NULL, "user7 = null");
     ok(unibi_get_str(ut, unibi_user8) == NULL, "user8 = null");
     ok(unibi_get_str(ut, unibi_user9) == NULL, "user9 = null");
-    ok(strcmp(unibi_get_str(ut, unibi_orig_pair), "\033[39;49m") == 0, "orig_pair = \"\\033[39;49m\"");
+    ok(strcmp(unibi_get_str(ut, unibi_orig_pair), "\033[39;49m") == 0, "orig_pair = \"%s\"", "\\033[39;49m");
     unibi_set_str(dt, unibi_orig_pair, "\033[39;49m");
     ok(unibi_get_str(ut, unibi_orig_colors) == NULL, "orig_colors = null");
     ok(unibi_get_str(ut, unibi_initialize_color) == NULL, "initialize_color = null");
@@ -673,14 +655,14 @@ int main(void) {
     ok(unibi_get_str(ut, unibi_these_cause_cr) == NULL, "these_cause_cr = null");
     ok(unibi_get_str(ut, unibi_zero_motion) == NULL, "zero_motion = null");
     ok(unibi_get_str(ut, unibi_char_set_names) == NULL, "char_set_names = null");
-    ok(strcmp(unibi_get_str(ut, unibi_key_mouse), "\033[M") == 0, "key_mouse = \"\\033[M\"");
+    ok(strcmp(unibi_get_str(ut, unibi_key_mouse), "\033[M") == 0, "key_mouse = \"%s\"", "\\033[M");
     unibi_set_str(dt, unibi_key_mouse, "\033[M");
     ok(unibi_get_str(ut, unibi_mouse_info) == NULL, "mouse_info = null");
     ok(unibi_get_str(ut, unibi_req_mouse_pos) == NULL, "req_mouse_pos = null");
     ok(unibi_get_str(ut, unibi_get_mouse) == NULL, "get_mouse = null");
-    ok(strcmp(unibi_get_str(ut, unibi_set_a_foreground), "\033[3%p1%dm") == 0, "set_a_foreground = \"\\033[3%p1%dm\"");
+    ok(strcmp(unibi_get_str(ut, unibi_set_a_foreground), "\033[3%p1%dm") == 0, "set_a_foreground = \"%s\"", "\\033[3%p1%dm");
     unibi_set_str(dt, unibi_set_a_foreground, "\033[3%p1%dm");
-    ok(strcmp(unibi_get_str(ut, unibi_set_a_background), "\033[4%p1%dm") == 0, "set_a_background = \"\\033[4%p1%dm\"");
+    ok(strcmp(unibi_get_str(ut, unibi_set_a_background), "\033[4%p1%dm") == 0, "set_a_background = \"%s\"", "\\033[4%p1%dm");
     unibi_set_str(dt, unibi_set_a_background, "\033[4%p1%dm");
     ok(unibi_get_str(ut, unibi_pkey_plab) == NULL, "pkey_plab = null");
     ok(unibi_get_str(ut, unibi_device_type) == NULL, "device_type = null");
@@ -736,52 +718,52 @@ int main(void) {
     ok(unibi_get_str(ut, unibi_memory_unlock) == NULL, "memory_unlock = null");
     ok(unibi_get_str(ut, unibi_box_chars_1) == NULL, "box_chars_1 = null");
 
-    diag("extended boolean capabilities");
+    note("extended boolean capabilities");
     {
         const size_t n_ext = unibi_count_ext_bool(ut);
         ok(n_ext == 3, "#ext_bool = 3");
         ok(0 < n_ext && unibi_get_ext_bool(ut, 0) == 1, "ext_bool[0].value = 1");
-        ok(0 < n_ext && strcmp(unibi_get_ext_bool_name(ut, 0), "AX") == 0, "ext_bool[0].name = \"AX\"");
+        ok(0 < n_ext && strcmp(unibi_get_ext_bool_name(ut, 0), "AX") == 0, "ext_bool[0].name = \"%s\"", "AX");
         unibi_add_ext_bool(dt, "AX", 1);
         ok(1 < n_ext && unibi_get_ext_bool(ut, 1) == 1, "ext_bool[1].value = 1");
-        ok(1 < n_ext && strcmp(unibi_get_ext_bool_name(ut, 1), "G0") == 0, "ext_bool[1].name = \"G0\"");
+        ok(1 < n_ext && strcmp(unibi_get_ext_bool_name(ut, 1), "G0") == 0, "ext_bool[1].name = \"%s\"", "G0");
         unibi_add_ext_bool(dt, "G0", 1);
         ok(2 < n_ext && unibi_get_ext_bool(ut, 2) == 0, "ext_bool[2].value = 0");
-        ok(2 < n_ext && strcmp(unibi_get_ext_bool_name(ut, 2), "XT") == 0, "ext_bool[2].name = \"XT\"");
+        ok(2 < n_ext && strcmp(unibi_get_ext_bool_name(ut, 2), "XT") == 0, "ext_bool[2].name = \"%s\"", "XT");
         unibi_add_ext_bool(dt, "XT", 0);
     }
 
-    diag("extended numeric capabilities");
+    note("extended numeric capabilities");
     {
         const size_t n_ext = unibi_count_ext_num(ut);
         ok(n_ext == 1, "#ext_num = 1");
         ok(0 < n_ext && unibi_get_ext_num(ut, 0) == 1, "ext_num[0].value = 1");
-        ok(0 < n_ext && strcmp(unibi_get_ext_num_name(ut, 0), "U8") == 0, "ext_num[0].name = \"U8\"");
+        ok(0 < n_ext && strcmp(unibi_get_ext_num_name(ut, 0), "U8") == 0, "ext_num[0].name = \"%s\"", "U8");
         unibi_add_ext_num(dt, "U8", 1);
     }
 
-    diag("extended string capabilities");
+    note("extended string capabilities");
     {
         const size_t n_ext = unibi_count_ext_str(ut);
         ok(n_ext == 6, "#ext_str = 6");
-        ok(0 < n_ext && strcmp(unibi_get_ext_str(ut, 0), "\033(B") == 0, "ext_str[0].value = \"\\033(B\"");
+        ok(0 < n_ext && strcmp(unibi_get_ext_str(ut, 0), "\033(B") == 0, "ext_str[0].value = \"%s\"", "\\033(B");
         unibi_add_ext_str(dt, "E0", "\033(B");
-        ok(0 < n_ext && strcmp(unibi_get_ext_str_name(ut, 0), "E0") == 0, "ext_str[0].name = \"E0\"");
-        ok(1 < n_ext && strcmp(unibi_get_ext_str(ut, 1), "\033(%p1%c") == 0, "ext_str[1].value = \"\\033(%p1%c\"");
+        ok(0 < n_ext && strcmp(unibi_get_ext_str_name(ut, 0), "E0") == 0, "ext_str[0].name = \"%s\"", "E0");
+        ok(1 < n_ext && strcmp(unibi_get_ext_str(ut, 1), "\033(%p1%c") == 0, "ext_str[1].value = \"%s\"", "\\033(%p1%c");
         unibi_add_ext_str(dt, "S0", "\033(%p1%c");
-        ok(1 < n_ext && strcmp(unibi_get_ext_str_name(ut, 1), "S0") == 0, "ext_str[1].name = \"S0\"");
+        ok(1 < n_ext && strcmp(unibi_get_ext_str_name(ut, 1), "S0") == 0, "ext_str[1].name = \"%s\"", "S0");
         ok(2 < n_ext && unibi_get_ext_str(ut, 2) == NULL, "ext_str[2].value = null");
         unibi_add_ext_str(dt, "ka2", NULL);
-        ok(2 < n_ext && strcmp(unibi_get_ext_str_name(ut, 2), "ka2") == 0, "ext_str[2].name = \"ka2\"");
+        ok(2 < n_ext && strcmp(unibi_get_ext_str_name(ut, 2), "ka2") == 0, "ext_str[2].name = \"%s\"", "ka2");
         ok(3 < n_ext && unibi_get_ext_str(ut, 3) == NULL, "ext_str[3].value = null");
         unibi_add_ext_str(dt, "kb1", NULL);
-        ok(3 < n_ext && strcmp(unibi_get_ext_str_name(ut, 3), "kb1") == 0, "ext_str[3].name = \"kb1\"");
+        ok(3 < n_ext && strcmp(unibi_get_ext_str_name(ut, 3), "kb1") == 0, "ext_str[3].name = \"%s\"", "kb1");
         ok(4 < n_ext && unibi_get_ext_str(ut, 4) == NULL, "ext_str[4].value = null");
         unibi_add_ext_str(dt, "kb3", NULL);
-        ok(4 < n_ext && strcmp(unibi_get_ext_str_name(ut, 4), "kb3") == 0, "ext_str[4].name = \"kb3\"");
+        ok(4 < n_ext && strcmp(unibi_get_ext_str_name(ut, 4), "kb3") == 0, "ext_str[4].name = \"%s\"", "kb3");
         ok(5 < n_ext && unibi_get_ext_str(ut, 5) == NULL, "ext_str[5].value = null");
         unibi_add_ext_str(dt, "kc2", NULL);
-        ok(5 < n_ext && strcmp(unibi_get_ext_str_name(ut, 5), "kc2") == 0, "ext_str[5].name = \"kc2\"");
+        ok(5 < n_ext && strcmp(unibi_get_ext_str_name(ut, 5), "kc2") == 0, "ext_str[5].name = \"%s\"", "kc2");
     }
 
     {
@@ -808,8 +790,5 @@ int main(void) {
 }
 
 static void setup(void) {
-    setvbuf(stdout, NULL, _IOLBF, 0);
-
     plan(531);
-    test_counter = 1;
 }
